//
//  TikTokOpenPlatformAuth.h
//  AFgzipRequestSerializer
//
//  Created by Spiker on 2019/7/8.
//

#import "TikTokOpenPlatformObjects.h"
#import "TiktokOpenPlatformApplicationDelegate.h"

NS_ASSUME_NONNULL_BEGIN
@class TikTokOpenPlatformAuthRespond;

typedef void(^TikTokAuthCompleteBlock)(TikTokOpenPlatformAuthRespond *resp);

#pragma mark - Auth Request
@interface TikTokOpenPlatformAuthRequest : TikTokOpenPlatformBaseRequest

- (instancetype)init  __attribute__((unavailable("use -initWithAppType: for initialization")));
- (instancetype)initWithAppType:(TikTokOpenPlatformAppType)appType NS_DESIGNATED_INITIALIZER;

@property (nonatomic, assign, readonly) TikTokOpenPlatformAppType appType;
/**
 第三方应用程序向Tiktok申请的必需权限类型，最终在TiktokApp授权完成后根据实际授权结果返回给第三方应用；
 例如 [NSOrderedSet orderedSetWithObjects:@"user_info", ..., nil]
 */
@property (nonatomic, strong, nullable) NSOrderedSet<NSString *> *permissions;

/**
 第三方应用程序向Tiktok申请的附加权限类型，用户可以勾选是否给予这部分权限，最终在TiktokApp授权完成后根据实际授权结果返回给第三方应用；
 @key permission 权限
 @key defaultChecked 初始勾选状态，@"1"表示勾选，@"0"表示未勾选
 例如 [NSOrderedSet orderedSetWithObjects:@{@"permission":@"user_info",@"defaultChecked":@"0"}, ..., nil]
 */
@property (nonatomic, strong, nullable) NSOrderedSet<NSDictionary<NSString *,NSString *> *> *additionalPermissions;

/**
 第三方应用程序用来标识请求的唯一性，最后跳转回第三方程序时由TiktokApp回传
 */
@property (nonatomic, copy, nullable) NSString *state;

- (BOOL)sendAuthRequestViewController:(UIViewController *)viewController completeBlock:(TikTokAuthCompleteBlock)completed;

@end


#pragma mark - Auth Respond
@interface TikTokOpenPlatformAuthRespond : TikTokOpenPlatformBaseRespond

/**
 第三方应用向Tiktok申请某些权限，最终在TiktokApp授权完成后根据实际授权结果返回给第三方应用
 */
@property (nonatomic, copy, readonly, nullable) NSString *code;

/**
 第三方应用程序用来标识请求的唯一性，最后跳转回第三方程序时由Tiktok回传
 */
@property (nonatomic, copy, readonly, nullable) NSString *state;

/**
 Tiktok用户同意给予第三方应用程序的权限，若授权成功则包括全部必需权限和用户勾选的附加权限；
 */
@property (nonatomic, strong, nullable) NSOrderedSet<NSString *> *grantedPermissions;

@end


NS_ASSUME_NONNULL_END
