//
//  TikTokOpenPlatformShareRequest.h
//  AFgzipRequestSerializer
//
//  Created by Spiker on 2019/7/8.
//

#import "TikTokOpenPlatformObjects.h"
#import "TiktokOpenPlatformApplicationDelegate.h"

NS_ASSUME_NONNULL_BEGIN

typedef NS_ENUM(NSUInteger, TiktokOpenPlatformShareMediaType) {
    TiktokOpenPlatformShareMediaTypeImage = 0, // 对应 PHAssetMediaTypeImage
    TiktokOpenPlatformShareMediaTypeVideo, // 对应 PHAssetMediaTypeVideo
};
@class TikTokOpenPlatformShareRespond;

typedef void(^TikTokShareCompleteBlock)(TikTokOpenPlatformShareRespond *respond);

@interface TikTokOpenPlatformShareRequest : TikTokOpenPlatformBaseRequest

- (instancetype)init  __attribute__((unavailable("use -initWithAppType: for initialization")));

- (instancetype)initWithAppType:(TikTokOpenPlatformAppType)appType NS_DESIGNATED_INITIALIZER;

@property (nonatomic, readonly) TikTokOpenPlatformAppType appType;
/**
 第三方应用程序向抖音短视频分享的视频或图片在 **相册** 中的中的local identifier，上限为12个，内容须全部为图片，或者全部为视频。
 若内容为视频，视频总时长应该大于3s；
 图片的宽高比应满足：1/2.2<=宽高比<=2.2；
 视频分辨率应满足：1/2.2<=宽高像素比<=2.2；
 请三方应用程序自行检查分享的内容是否满足要求；
 此处需注意，带品牌logo或品牌水印的视频，会命中抖音的审核逻辑，有比较大的概率导致分享视频推荐降权处理/分享视频下架处理/分享账号被封禁处理，请予以重视；
 强烈建议第三方应用自行处理好分享内容中的不合规水印。
 */
@property (nonatomic, strong) NSArray *localIdentifiers;

/**
 对应视频的 #话题 功能，需要额外申请权限，字符长度不能超过 35
 */
@property (nonatomic, copy) NSString *hashtag;

/**
 urlPaths在相册中对应的Media类型，urlPaths里面的必须都是同一种类型
 */
@property (nonatomic, assign) TiktokOpenPlatformShareMediaType mediaType;

/**
 第三方应用程序用来标识请求的唯一性，最后跳转回第三方程序时由抖音短视频App回传
 */
@property (nonatomic, copy, nullable) NSString *state;

/**
 第三方应用程序拓展字段
 */
@property (nonatomic, copy, nullable) NSDictionary *extraInfo;

- (BOOL)sendShareRequestWithCompleteBlock:(TikTokShareCompleteBlock) completed;
@end

@interface TikTokOpenPlatformShareRespond : TikTokOpenPlatformBaseRespond

@property (nonatomic, copy, nullable) NSString *state;

@end

NS_ASSUME_NONNULL_END
